@@ -11,6 +11,8 @@ struct _EogImageCachePrivate {
 
 #define CACHE_DEBUG  0
 
+G_DEFINE_TYPE (EogImageCache, eog_image_cache, G_TYPE_OBJECT)
+
 static void
 eog_image_cache_finalize (GObject *object)
 {
@@ -18,6 +20,8 @@ eog_image_cache_finalize (GObject *object)
 	
 	g_free (instance->priv);
 	instance->priv = NULL;
+
+	G_OBJECT_CLASS (eog_image_cache_parent_class)->finalize (object);
 }
 
 static void
@@ -38,6 +42,8 @@ eog_image_cache_dispose (GObject *object)
 		g_queue_free (priv->queue);
 		priv->queue = NULL;
 	}
+
+	G_OBJECT_CLASS (eog_image_cache_parent_class)->dispose (object);
 }
 
 static void
@@ -61,8 +67,6 @@ eog_image_cache_class_init (EogImageCacheClass *klass)
 	object_class->dispose = eog_image_cache_dispose;
 }
 
-G_DEFINE_TYPE (EogImageCache, eog_image_cache, G_TYPE_OBJECT)
-
 EogImageCache*      
 eog_image_cache_new (int n)
 {
