@@ -236,7 +236,7 @@ eog_preferences_show (GtkWindow *parent, GConfClient *client)
 				   gconf_client_get_int (client, EOG_CONF_FULLSCREEN_SECONDS, NULL));
 	g_object_set_data (G_OBJECT (widget), GCONF_OBJECT_KEY, EOG_CONF_FULLSCREEN_SECONDS);
 	g_signal_connect (G_OBJECT (widget), 
-			  "changed", 
+			  "value-changed", 
 			  G_CALLBACK (spin_button_changed_cb), 
 			  client);
 			  
